@@ -1,5 +1,6 @@
 from contextlib import contextmanager
-from typing import Any, Generator, Mapping, Optional, Type
+import datetime
+from typing import Any, Dict, Generator, Mapping, Optional, Type
 
 from django.conf import settings
 from django.contrib.auth import get_user_model
@@ -114,6 +115,12 @@ class Event(PolymorphicModel):
         related_name='events',
         related_query_name='event',
     )
+    delay = models.DurationField(
+        _('delay'),
+        default=datetime.timedelta(),
+        blank=True,
+        help_text=_('Delay from the moment when the event actually happened until it should be handled.'),
+    )
     fired = Signal()
 
     class Meta:
@@ -126,7 +133,7 @@ class Event(PolymorphicModel):
     def should_be_fired(self, **kwargs) -> bool:
         return True
 
-    def get_user_context(self, user, context) -> Mapping[str, Any]:
+    def get_user_context(self, user, context: Mapping[str, Any]) -> Dict[str, Any]:
         user_context = {'user': user}
         user_context.update(context)
         return user_context
@@ -196,7 +203,7 @@ class ActionCountCondition(Condition):  # type: ignore[django-manager-missing]
         verbose_name_plural = _('action count')
 
     def __str__(self):
-        return f'{super().__str__()} less than {self.limit}'
+        return f'{super().__str__()} no more than {self.limit}'
 
     @property
     def exclude_users_q(self) -> Optional[models.Q]:
@@ -218,7 +225,7 @@ class ActionFrequencyCondition(Condition):  # type: ignore[django-manager-missin
         verbose_name_plural = _('action frequency')
 
     def __str__(self):
-        return f'{super().__str__()} less than {self.limit}'
+        return f'{super().__str__()} no less than {self.limit}'
 
     @property
     def exclude_users_q(self) -> Optional[models.Q]:
